==> ZenTaoPMS.max2.0.rc1.php7.0.zip: zentaopms/module/feedback/lang/vi.php <==
<?php
$lang->feedback->common    = 'Phản hồi';
$lang->feedback->module    = 'Module';
$lang->feedback->moduleAB  = 'Module';
$lang->feedback->manageCate   = 'Quản lý danh mục';
$lang->feedback->index  = 'Trang phản hồi';
$lang->feedback->create    = 'Thêm phản hồi';
$lang->feedback->edit   = 'Sửa phản hồi';
$lang->feedback->createFaq = 'Thêm FAQ';
$lang->feedback->faq    = 'FAQ';
$lang->feedback->nonRDBrowse  = 'Giao diện phản hồi';
$lang->feedback->browse    = 'Danh sách phản hồi';
$lang->feedback->list   = 'Phản hồi';
$lang->feedback->header    = 'Phản hồi';
$lang->feedback->view   = 'Chi tiết phản hồi';
$lang->feedback->review    = 'Xét duyệt';
$lang->feedback->reviewAction = 'Duyệt phản hồi';
$lang->feedback->adminView = 'Giao diện phát triển';
$lang->feedback->close  = 'Đóng';
$lang->feedback->closeAction  = 'Đóng phản hồi';
$lang->feedback->feelLike  = ' Thích!';
$lang->feedback->ask    = 'Nghi ngờ';
$lang->feedback->toStory   = 'Tới ' . $lang->SRCommon;
$lang->feedback->toTask    = 'Tới nhiệm vụ';
$lang->feedback->toBug  = 'Tới Bug';
$lang->feedback->toTodo    = 'Tới việc làm';
$lang->feedback->story  = $lang->SRCommon;
$lang->feedback->bug    = 'Bug';
$lang->feedback->todo   = 'Việc làm';
$lang->feedback->task   = 'Nhiệm vụ';
$lang->feedback->reply  = 'Trả lời';
$lang->feedback->replyAction  = 'Trả lời phản hồi';
$lang->feedback->convert   = 'Chuyển đổi';
$lang->feedback->assign    = 'Giao cho';
$lang->feedback->assignAction = 'Bàn giao phản hồi';
$lang->feedback->export    = 'Xuất';
$lang->feedback->exportAction = 'Xuất phản hồi';
$lang->feedback->assignTo  = 'Giao cho';
$lang->feedback->mailto    = 'Mail tới';
$lang->feedback->delete    = 'Xóa phản hồi';
$lang->feedback->mailNotify   = 'Thông báo Email';
$lang->feedback->search    = 'Tìm kiếm';
$lang->feedback->comment   = 'Nhận xét';
$lang->feedback->products  = 'Phân quyền';
$lang->feedback->batchEdit = 'Sửa hàng loạt';
$lang->feedback->batchClose   = 'Đóng hàng loạt';
$lang->feedback->batchReview    = 'Duyệt hàng loạt';
$lang->feedback->batchAssignTo  = 'Bàn giao hàng loạt';
$lang->feedback->batchChangeModule = 'Thay đổi Module hàng loạt';
$lang->feedback->manageProduct  = 'Quản lý quyền người dùng';

$lang->feedback->id    = 'ID';
$lang->feedback->product  = $lang->productCommon;
$lang->feedback->title    = 'Tiêu đề';
$lang->feedback->desc     = 'Mô tả';
$lang->feedback->status   = 'Tình trạng';
$lang->feedback->subStatus   = 'Tình trạng con';
$lang->feedback->openedBy    = 'Người thêm';
$lang->feedback->openedDate  = 'Ngày mở';
$lang->feedback->processedBy = 'Người trả lời';
$lang->feedback->processedDate  = 'Đã trả lời';
$lang->feedback->reviewedBy  = 'Người duyệt';
$lang->feedback->reviewedDate   = 'Đã duyệt';
$lang->feedback->reviewResult   = 'Kết quả xét duyệt';
$lang->feedback->reviewedByAB   = 'Người duyệt';
$lang->feedback->reviewedDateAB = 'Ngày';
$lang->feedback->reviewResultAB = 'Kết quả';
$lang->feedback->assignedTo  = 'Giao cho';
$lang->feedback->assignedDate   = 'Đã giao';
$lang->feedback->closedBy    = 'Người đóng';
$lang->feedback->closedDate  = 'Ngày đóng';
$lang->feedback->closedReason   = 'Lý do đóng';
$lang->feedback->public   = 'Công khai';
$lang->feedback->notify   = 'Thông báo';
$lang->feedback->likes    = 'Thích';
$lang->feedback->result   = 'Kết quả';
$lang->feedback->files    = 'Files';
$lang->feedback->labelBasic  = 'Cơ bản';
$lang->feedback->dept     = 'Phòng/Ban';
$lang->feedback->editedBy    = 'Người sửa';
$lang->feedback->editedDate  = 'Sửa lần cuối';
$lang->feedback->contactInfo = 'Liên hệ';
$lang->feedback->noAssigned  = 'Chưa giao';
$lang->feedback->deptManager = 'Trưởng phòng';
$lang->feedback->reviewOpinion  = 'Duyệt ý kiến';
$lang->feedback->deleted        = 'Đã xóa';
$lang->feedback->execution      = 'Select sprint/stage';

$lang->feedback->lblBasic       = 'Thông tin cơ bản';
$lang->feedback->lblTrace       = 'Traceability Diagram';
$lang->feedback->assigntome     = 'Giao cho bạn';
$lang->feedback->allProduct     = 'Tất cả ' . $lang->productCommon;
$lang->feedback->nextStep       = 'Next';
$lang->feedback->selectProjects = 'Select Projects';

$lang->feedback->grantUser   = 'Người dùng đã xác thực';
$lang->feedback->noGrantUser = 'Người dùng chưa xác thực';
$lang->feedback->hasPrivUser = 'Người dùng phản hồi có phân quyền mặc định cho tất cả sản phẩm. If any privilege is assigned, they will have the privileges of the related product.';

$lang->feedback->tabList['unclosed'] = 'Chưa đóng';
$lang->feedback->tabList['all']   = 'Tất cả';
$lang->feedback->tabList['public']   = 'Công khai';

$lang->feedback->reviewResultList['']  = '';
$lang->feedback->reviewResultList['pass'] = 'Đạt';
$lang->feedback->reviewResultList['clarify'] = 'Đã làm rõ';

$lang->feedback->statusList['']     = '';
$lang->feedback->statusList['noreview']   = 'Chờ duyệt';
$lang->feedback->statusList['clarify'] = 'Đã làm rõ';
$lang->feedback->statusList['wait']    = 'Đang đợi';
$lang->feedback->statusList['commenting'] = 'Đang làm';
$lang->feedback->statusList['replied'] = 'Đã trả lời';
$lang->feedback->statusList['asked']   = 'Doubted';
$lang->feedback->statusList['tobug']   = 'Chuyển thành Bug';
$lang->feedback->statusList['tostory'] = 'Chuyển thành ' . $lang->SRCommon;
$lang->feedback->statusList['totask']  = 'Chuyển thành nhiệm vụ';
$lang->feedback->statusList['totodo']  = 'Chuyển thành việc làm';
$lang->feedback->statusList['closed']  = 'Đã đóng';

$lang->feedback->closedReasonList[]   = '';
$lang->feedback->closedReasonList['commented'] = 'Đã trả lời';
$lang->feedback->closedReasonList['tobug']  = 'Chuyển thành Bug';
$lang->feedback->closedReasonList['tostory']   = 'Chuyển thành ' . $lang->SRCommon;
$lang->feedback->closedReasonList['totask'] = 'Chuyển thành nhiệm vụ';
$lang->feedback->closedReasonList['totodo'] = 'Chuyển thành việc làm';
$lang->feedback->closedReasonList['repeat'] = 'Lặp lại';
$lang->feedback->closedReasonList['refuse'] = 'Từ chối';

$lang->feedback->publicList['']  = '';
$lang->feedback->publicList['0'] = 'Riêng tư';
$lang->feedback->publicList['1'] = 'Công khai';

$lang->feedback->confirmDelete = 'Bạn có muốn xóa phản hồi này?';
$lang->feedback->confirmClose  = 'Bạn có muốn đóng phản hồi này?';
$lang->feedback->noProject     = 'Haven’t chosen a project yet';

$lang->feedback->commented  = '$date, trả lời bởi <strong>$actor</strong>.' . "\n";
$lang->feedback->noModule   = '<div>Bạn không có danh mục.</div>';
$lang->feedback->mustChooseResult = 'Chọn kết quả';

$lang->feedback->action = new stdclass();
$lang->feedback->action->closed   = array('main' => '$date, được đóng bởi <strong>$actor</strong>. Close Reason is <strong>$extra</strong>.', 'extra' => 'closedReasonList');   
$lang->feedback->action->reviewed = array('main' => '$date, xét duyệt bởi <strong>$actor</strong>. Kết quả là <strong>$extra</strong>.', 'extra' => 'reviewResultList');

==> ZenTaoPMS.max2.2.php7.0.zip: zentaopms/module/feedback/lang/vi.php <==
<?php
$lang->feedback->common            = 'Phản hồi';
$lang->feedback->module            = 'Module';
$lang->feedback->moduleAB          = 'Module';
$lang->feedback->manageCate        = 'Quản lý danh mục';
$lang->feedback->index             = 'Trang phản hồi';
$lang->feedback->create            = 'Thêm phản hồi';
$lang->feedback->edit              = 'Sửa phản hồi';
$lang->feedback->createFaq         = 'Thêm FAQ';
$lang->feedback->faq               = 'FAQ';
$lang->feedback->nonRDBrowse       = 'Giao diện phản hồi';
$lang->feedback->browse            = 'Danh sách phản hồi';
$lang->feedback->list              = 'Phản hồi';
$lang->feedback->header            = 'Phản hồi';
$lang->feedback->view              = 'Chi tiết phản hồi';
$lang->feedback->review            = 'Xét duyệt';
$lang->feedback->reviewAction      = 'Duyệt phản hồi';
$lang->feedback->adminView         = 'Giao diện phát triển';
$lang->feedback->close             = 'Đóng';
$lang->feedback->closeAction       = 'Đóng phản hồi';
$lang->feedback->feelLike          = ' Thích!';
$lang->feedback->ask               = 'Nghi ngờ';
$lang->feedback->toStory           = 'Tới ' . $lang->SRCommon;
$lang->feedback->toTask            = 'Tới nhiệm vụ';
$lang->feedback->toBug             = 'Tới Bug';
$lang->feedback->toTodo            = 'Tới việc làm';
$lang->feedback->story             = $lang->SRCommon;
$lang->feedback->bug               = 'Bug';
$lang->feedback->todo              = 'Việc làm';
$lang->feedback->task              = 'Nhiệm vụ';
$lang->feedback->reply             = 'Trả lời';
$lang->feedback->replyAction       = 'Trả lời phản hồi';
$lang->feedback->convert           = 'Chuyển đổi';
$lang->feedback->assign            = 'Giao cho';
$lang->feedback->assignAction      = 'Bàn giao phản hồi';
$lang->feedback->export            = 'Xuất';
$lang->feedback->exportAction      = 'Xuất phản hồi';
$lang->feedback->assignTo          = 'Giao cho';
$lang->feedback->mailto            = 'Mail tới';
$lang->feedback->delete            = 'Xóa phản hồi';
$lang->feedback->mailNotify        = 'Thông báo Email';
$lang->feedback->search            = 'Tìm kiếm';
$lang->feedback->comment           = 'Nhận xét';
$lang->feedback->products          = 'Phân quyền';
$lang->feedback->batchEdit         = 'Sửa hàng loạt';
$lang->feedback->batchClose        = 'Đóng hàng loạt';
$lang->feedback->batchReview       = 'Duyệt hàng loạt';
$lang->feedback->batchAssignTo     = 'Bàn giao hàng loạt';
$lang->feedback->batchChangeModule = 'Thay đổi Module hàng loạt';
$lang->feedback->manageProduct     = 'Quản lý quyền người dùng';
$lang->feedback->consumed          = 'Đã làm';

$lang->feedback->id    = 'ID';
$lang->feedback->product  = $lang->productCommon;
$lang->feedback->title    = 'Tiêu đề';
$lang->feedback->desc     = 'Mô tả';
$lang->feedback->status   = 'Tình trạng';
$lang->feedback->subStatus   = 'Tình trạng con';
$lang->feedback->openedBy    = 'Người thêm';
$lang->feedback->openedDate  = 'Ngày mở';
$lang->feedback->processedBy = 'Người trả lời';
$lang->feedback->processedDate  = 'Đã trả lời';
$lang->feedback->reviewedBy  = 'Người duyệt';
$lang->feedback->reviewedDate   = 'Đã duyệt';
$lang->feedback->reviewResult   = 'Kết quả xét duyệt';
$lang->feedback->reviewedByAB   = 'Người duyệt';
$lang->feedback->reviewedDateAB = 'Ngày';
$lang->feedback->reviewResultAB = 'Kết quả';
$lang->feedback->assignedTo  = 'Giao cho';
$lang->feedback->assignedDate   = 'Đã giao';
$lang->feedback->closedBy    = 'Người đóng';
$lang->feedback->closedDate  = 'Ngày đóng';
$lang->feedback->closedReason   = 'Lý do đóng';
$lang->feedback->public   = 'Công khai';
$lang->feedback->notify   = 'Thông báo';
$lang->feedback->likes    = 'Thích';
$lang->feedback->result   = 'Kết quả';
$lang->feedback->files    = 'Files';
$lang->feedback->labelBasic  = 'Cơ bản';
$lang->feedback->dept     = 'Phòng/Ban';
$lang->feedback->editedBy    = 'Người sửa';
$lang->feedback->editedDate  = 'Sửa lần cuối';
$lang->feedback->contactInfo = 'Liên hệ';
$lang->feedback->noAssigned  = 'Chưa giao';
$lang->feedback->deptManager = 'Trưởng phòng';
$lang->feedback->reviewOpinion  = 'Duyệt ý kiến';
$lang->feedback->deleted        = 'Đã xóa';
$lang->feedback->execution      = 'Select sprint/stage';

$lang->feedback->lblBasic       = 'Thông tin cơ bản';
$lang->feedback->lblTrace       = 'Traceability Diagram';
$lang->feedback->assigntome     = 'Giao cho bạn';
$lang->feedback->allProduct     = 'Tất cả ' . $lang->productCommon;
$lang->feedback->nextStep       = 'Next';
$lang->feedback->selectProjects = 'Select Projects';

$lang->feedback->grantUser   = 'Người dùng đã xác thực';
$lang->feedback->noGrantUser = 'Người dùng chưa xác thực';
$lang->feedback->hasPrivUser = 'Người dùng phản hồi có phân quyền mặc định cho tất cả sản phẩm. If any privilege is assigned, they will have the privileges of the related product.';

$lang->feedback->tabList['unclosed'] = 'Chưa đóng';
$lang->feedback->tabList['all']   = 'Tất cả';
$lang->feedback->tabList['public']   = 'Công khai';

$lang->feedback->reviewResultList['']  = '';
$lang->feedback->reviewResultList['pass'] = 'Đạt';
$lang->feedback->reviewResultList['clarify'] = 'Đã làm rõ';

$lang->feedback->statusList['']     = '';
$lang->feedback->statusList['noreview']   = 'Chờ duyệt';
$lang->feedback->statusList['clarify'] = 'Đã làm rõ';
$lang->feedback->statusList['wait']    = 'Đang đợi';
$lang->feedback->statusList['commenting'] = 'Đang làm';
$lang->feedback->statusList['replied'] = 'Đã trả lời';
$lang->feedback->statusList['asked']   = 'Doubted';
$lang->feedback->statusList['tobug']   = 'Chuyển thành Bug';
$lang->feedback->statusList['tostory'] = 'Chuyển thành ' . $lang->SRCommon;
$lang->feedback->statusList['totask']  = 'Chuyển thành nhiệm vụ';
$lang->feedback->statusList['totodo']  = 'Chuyển thành việc làm';
$lang->feedback->statusList['closed']  = 'Đã đóng';

$lang->feedback->closedReasonList[]   = '';
$lang->feedback->closedReasonList['commented'] = 'Đã trả lời';
$lang->feedback->closedReasonList['tobug']  = 'Chuyển thành Bug';
$lang->feedback->closedReasonList['tostory']   = 'Chuyển thành ' . $lang->SRCommon;
$lang->feedback->closedReasonList['totask'] = 'Chuyển thành nhiệm vụ';
$lang->feedback->closedReasonList['totodo'] = 'Chuyển thành việc làm';
$lang->feedback->closedReasonList['repeat'] = 'Lặp lại';
$lang->feedback->closedReasonList['refuse'] = 'Từ chối';

$lang->feedback->publicList['']  = '';
$lang->feedback->publicList['0'] = 'Riêng tư';
$lang->feedback->publicList['1'] = 'Công khai';

$lang->feedback->confirmDelete = 'Bạn có muốn xóa phản hồi này?';
$lang->feedback->confirmClose  = 'Bạn có muốn đóng phản hồi này?';
$lang->feedback->noProject     = 'Haven’t chosen a project yet';

$lang->feedback->commented  = '$date, trả lời bởi <strong>$actor</strong>.' . "\n";
$lang->feedback->noModule   = '<div>Bạn không có danh mục.</div>';
$lang->feedback->mustChooseResult = 'Chọn kết quả';

$lang->feedback->action = new stdclass();
$lang->feedback->action->closed   = array('main' => '$date, được đóng bởi <strong>$actor</strong>. Close Reason is <strong>$extra</strong>.', 'extra' => 'closedReasonList');
$lang->feedback->action->reviewed = array('main' => '$date, xét duyệt bởi <strong>$actor</strong>. Kết quả là <strong>$extra</strong>.', 'extra' => 'reviewResultList');
